@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Moo;
 use strictures 2;
@@ -155,7 +155,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -247,14 +247,14 @@ Send a MIDI B<event> to the output port when the B<delay_time> expires.
 
   $rtc->run;
 
-Run the B<loop>!
+Run the asynchronous B<loop>!
 
 =head2 add_filter
 
-  $rtc->add_filter($event_type, $action);
+  $rtc->add_filter($event_type => $action);
 
 Add a filter, defined by the CODE reference B<action>, for an
-B<event_type> like C<note_on> or B<note_off>.
+B<event_type> like C<note_on> or C<note_off>.
 
 =head1 SEE ALSO
 
